Examples
========

You can have a look to the BiSO and the PubPart examples.

BiSO stands for "Bilan de la Science Ouverte" (Open Science Report).

PubPart stands for "Publications and Partnerships".

.. toctree::
   :maxdepth: 1

   notebooks/biso
   notebooks/pubpart
